***
API
***

Public
======

.. py:module:: pydiverse.common

.. autoclass:: Dtype
.. autoclass:: Bool
.. autoclass:: Date
.. autoclass:: Datetime
.. autoclass:: Decimal
.. autoclass:: Duration
.. autoclass:: Float
.. autoclass:: Float32
.. autoclass:: Float64
.. autoclass:: Int
.. autoclass:: Int8
.. autoclass:: Int16
.. autoclass:: Int32
.. autoclass:: Int64
.. autoclass:: NullType
.. autoclass:: String
.. autoclass:: Time
.. autoclass:: Uint8
.. autoclass:: Uint16
.. autoclass:: Uint32
.. autoclass:: Uint64
.. autoclass:: List
.. autoclass:: PandasBackend
